@@ -1,11 +1,11 @@
-context("maps2")
+# context("maps2")
 
 # turning off because CIAdata load seems to be causing trouble for CRAN
 # should replace this with some other data
 
 if (FALSE) {
 gdpData <- CIAdata("GDP")      # load some world data
-gdpData <- gdpData %>% mutate(GDP5 = ntiles(-GDP, 5, format="rank"))
+gdpData <- gdpData |> mutate(GDP5 = ntiles(-GDP, 5, format="rank"))
 
 
 testthat::test_that("World Maps work", {
@@ -25,8 +25,8 @@ testthat::test_that("World Maps work", {
 }  # end if(FALSE)
 
 
-USArrests2 <- USArrests %>% mutate(state = row.names(.))
+USArrests2 <- USArrests |> tibble::rownames_to_column("state")
 testthat::test_that("US Maps work", {
-  wrapped_expect_doppelganger("usmaps1", mUSMap(USArrests2, key="state", fill = "UrbanPop"))
+  wrapped_expect_doppelganger("usmaps1", mUSMap(USArrests2, key = "state", fill = "UrbanPop"))
   
 })
